@@ -11,9 +11,11 @@
 # under the License.
 
 from openstack import cloud as openstack
+
 openstack.enable_logging()
 
 cloud = openstack.connect(cloud='fuga', region_name='cystack')
 image = cloud.get_image(
-    'Ubuntu 16.04 LTS - Xenial Xerus - 64-bit - Fuga Cloud Based Image')
+    'Ubuntu 16.04 LTS - Xenial Xerus - 64-bit - Fuga Cloud Based Image'
+)
 cloud.pprint(image)
