@@ -16,8 +16,7 @@ from openstack import resource
 from openstack import utils
 
 
-class Allocation(_common.ListMixin, resource.Resource):
-
+class Allocation(resource.Resource):
     resources_key = 'allocations'
     base_path = '/allocations'
 
@@ -32,12 +31,17 @@ class Allocation(_common.ListMixin, resource.Resource):
     commit_jsonpatch = True
 
     _query_mapping = resource.QueryParameters(
-        'node', 'resource_class', 'state',
-        fields={'name': 'fields', 'type': _common.comma_separated_list},
+        'node',
+        'resource_class',
+        'state',
+        'owner',
+        fields={'type': _common.fields_type},
     )
 
     # Allocation update is available since 1.57
-    _max_microversion = '1.57'
+    # Backfilling allocations is available since 1.58
+    # owner attribute is available since 1.60
+    _max_microversion = '1.60'
 
     #: The candidate nodes for this allocation.
     candidate_nodes = resource.Body('candidate_nodes', type=list)
@@ -53,8 +57,13 @@ class Allocation(_common.ListMixin, resource.Resource):
     links = resource.Body('links', type=list)
     #: The name of the allocation.
     name = resource.Body('name')
+    #: The node UUID or name to create the allocation against,
+    #: bypassing the normal allocation process.
+    node = resource.Body('node')
     #: UUID of the node this allocation belongs to.
     node_id = resource.Body('node_uuid')
+    #: The tenant who owns the object
+    owner = resource.Body('owner')
     #: The requested resource class.
     resource_class = resource.Body('resource_class')
     #: The state of the allocation.
@@ -84,18 +93,19 @@ class Allocation(_common.ListMixin, resource.Resource):
             return self
 
         for count in utils.iterate_timeout(
-                timeout,
-                "Timeout waiting for the allocation %s" % self.id):
+            timeout, f"Timeout waiting for the allocation {self.id}"
+        ):
             self.fetch(session)
 
             if self.state == 'error' and not ignore_error:
                 raise exceptions.ResourceFailure(
-                    "Allocation %(allocation)s failed: %(error)s" %
-                    {'allocation': self.id, 'error': self.last_error})
+                    f"Allocation {self.id} failed: {self.last_error}"
+                )
             elif self.state != 'allocating':
                 return self
 
             session.log.debug(
                 'Still waiting for the allocation %(allocation)s '
                 'to become active, the current state is %(state)s',
-                {'allocation': self.id, 'state': self.state})
+                {'allocation': self.id, 'state': self.state},
+            )
