@@ -31,7 +31,7 @@ FAKE = {
     'files': {'file1': 'content'},
     'files_container': 'dummy_container',
     'id': FAKE_ID,
-    'links': [{'href': 'stacks/%s/%s' % (FAKE_NAME, FAKE_ID), 'rel': 'self'}],
+    'links': [{'href': f'stacks/{FAKE_NAME}/{FAKE_ID}', 'rel': 'self'}],
     'notification_topics': '7',
     'outputs': '8',
     'parameters': {'OS::stack_id': '9'},
@@ -47,9 +47,7 @@ FAKE = {
 FAKE_CREATE_RESPONSE = {
     'stack': {
         'id': FAKE_ID,
-        'links': [
-            {'href': 'stacks/%s/%s' % (FAKE_NAME, FAKE_ID), 'rel': 'self'}
-        ],
+        'links': [{'href': f'stacks/{FAKE_NAME}/{FAKE_ID}', 'rel': 'self'}],
     }
 }
 FAKE_UPDATE_PREVIEW_RESPONSE = {
@@ -181,37 +179,30 @@ class TestStack(base.TestCase):
     @mock.patch.object(resource.Resource, 'create')
     def test_create(self, mock_create):
         sess = mock.Mock()
-        sot = stack.Stack(FAKE)
+        sot = stack.Stack()
 
         res = sot.create(sess)
 
-        mock_create.assert_called_once_with(
-            sess, prepend_key=False, base_path=None
-        )
+        mock_create.assert_called_once_with(sess, False)
         self.assertEqual(mock_create.return_value, res)
 
-    @mock.patch.object(resource.Resource, 'commit')
-    def test_commit(self, mock_commit):
-        sess = mock.Mock()
-        sot = stack.Stack(FAKE)
-
-        res = sot.commit(sess)
-
-        mock_commit.assert_called_once_with(
-            sess, prepend_key=False, has_body=False, base_path=None
-        )
-        self.assertEqual(mock_commit.return_value, res)
-
     def test_check(self):
         sess = mock.Mock()
         sot = stack.Stack(**FAKE)
         sot._action = mock.Mock()
+        sot._action.side_effect = [
+            test_resource.FakeResponse(None, 200, None),
+            exceptions.BadRequestException(message='oops'),
+            exceptions.NotFoundException(message='oops'),
+        ]
         body = {'check': ''}
 
         sot.check(sess)
-
         sot._action.assert_called_with(sess, body)
 
+        self.assertRaises(exceptions.BadRequestException, sot.check, sess)
+        self.assertRaises(exceptions.NotFoundException, sot.check, sess)
+
     def test_fetch(self):
         sess = mock.Mock()
         sess.default_microversion = None
@@ -225,7 +216,7 @@ class TestStack(base.TestCase):
             test_resource.FakeResponse(
                 {'stack': {'stack_status': 'CREATE_COMPLETE'}}, 200
             ),
-            exceptions.ResourceNotFound(message='oops'),
+            exceptions.NotFoundException(message='oops'),
             test_resource.FakeResponse(
                 {'stack': {'stack_status': 'DELETE_COMPLETE'}}, 200
             ),
@@ -233,20 +224,20 @@ class TestStack(base.TestCase):
 
         self.assertEqual(sot, sot.fetch(sess))
         sess.get.assert_called_with(
-            'stacks/{id}'.format(id=sot.id),
+            f'stacks/{sot.id}',
             microversion=None,
             skip_cache=False,
         )
         sot.fetch(sess, resolve_outputs=False)
         sess.get.assert_called_with(
-            'stacks/{id}?resolve_outputs=False'.format(id=sot.id),
+            f'stacks/{sot.id}?resolve_outputs=False',
             microversion=None,
             skip_cache=False,
         )
-        ex = self.assertRaises(exceptions.ResourceNotFound, sot.fetch, sess)
+        ex = self.assertRaises(exceptions.NotFoundException, sot.fetch, sess)
         self.assertEqual('oops', str(ex))
-        ex = self.assertRaises(exceptions.ResourceNotFound, sot.fetch, sess)
-        self.assertEqual('No stack found for %s' % FAKE_ID, str(ex))
+        ex = self.assertRaises(exceptions.NotFoundException, sot.fetch, sess)
+        self.assertEqual(f'No stack found for {FAKE_ID}', str(ex))
 
     def test_abandon(self):
         sess = mock.Mock()
@@ -262,10 +253,27 @@ class TestStack(base.TestCase):
         sot.abandon(sess)
 
         sess.delete.assert_called_with(
-            'stacks/%s/%s/abandon' % (FAKE_NAME, FAKE_ID),
+            f'stacks/{FAKE_NAME}/{FAKE_ID}/abandon',
         )
 
-    def test_update(self):
+    def test_export(self):
+        sess = mock.Mock()
+        sess.default_microversion = None
+
+        mock_response = mock.Mock()
+        mock_response.status_code = 200
+        mock_response.headers = {}
+        mock_response.json.return_value = {}
+        sess.get = mock.Mock(return_value=mock_response)
+        sot = stack.Stack(**FAKE)
+
+        sot.export(sess)
+
+        sess.get.assert_called_with(
+            f'stacks/{FAKE_NAME}/{FAKE_ID}/export',
+        )
+
+    def test_commit(self):
         sess = mock.Mock()
         sess.default_microversion = None
 
@@ -277,16 +285,16 @@ class TestStack(base.TestCase):
         sot = stack.Stack(**FAKE)
         body = sot._body.dirty.copy()
 
-        sot.update(sess)
+        sot.commit(sess)
 
         sess.put.assert_called_with(
-            '/stacks/%s/%s' % (FAKE_NAME, FAKE_ID),
+            f'/stacks/{FAKE_NAME}/{FAKE_ID}',
             headers={},
             microversion=None,
             json=body,
         )
 
-    def test_update_preview(self):
+    def test_commit_preview(self):
         sess = mock.Mock()
         sess.default_microversion = None
 
@@ -298,10 +306,10 @@ class TestStack(base.TestCase):
         sot = stack.Stack(**FAKE)
         body = sot._body.dirty.copy()
 
-        ret = sot.update(sess, preview=True)
+        ret = sot.commit(sess, preview=True)
 
         sess.put.assert_called_with(
-            'stacks/%s/%s/preview' % (FAKE_NAME, FAKE_ID),
+            f'stacks/{FAKE_NAME}/{FAKE_ID}/preview',
             headers={},
             microversion=None,
             json=body,
@@ -316,3 +324,39 @@ class TestStack(base.TestCase):
             FAKE_UPDATE_PREVIEW_RESPONSE['unchanged'], ret.unchanged
         )
         self.assertEqual(FAKE_UPDATE_PREVIEW_RESPONSE['updated'], ret.updated)
+
+    def test_suspend(self):
+        sess = mock.Mock()
+
+        mock_response = mock.Mock()
+        mock_response.status_code = 200
+        mock_response.headers = {}
+        mock_response.json.return_value = {}
+        sess.post = mock.Mock(return_value=mock_response)
+        url = f"stacks/{FAKE_ID}/actions"
+        body = {"suspend": None}
+        sot = stack.Stack(**FAKE)
+
+        res = sot.suspend(sess)
+
+        self.assertIsNone(res)
+        sess.post.assert_called_with(url, json=body, microversion=None)
+
+    def test_resume(self):
+        sess = mock.Mock()
+
+        mock_response = mock.Mock()
+        mock_response.status_code = 200
+        mock_response.headers = {}
+        mock_response.json.return_value = {}
+        sess.post = mock.Mock(return_value=mock_response)
+        url = f"stacks/{FAKE_ID}/actions"
+
+        body = {"resume": None}
+
+        sot = stack.Stack(**FAKE)
+
+        res = sot.resume(sess)
+
+        self.assertIsNone(res)
+        sess.post.assert_called_with(url, json=body, microversion=None)
